uniform mat4 modelMatrix;
uniform mat4 viewMatrix;
uniform mat4 projMatrix;

layout(location = 0) in vec3 inPosition;
layout(location = 1) in vec4 inColor;
layout(location = 2) in vec2 inTexCoord;
layout(location = 3) in vec3 inNormal;

out vec3 position;
out vec4 color;
out vec2 texCoord;
out vec3 normal;

void main(void)
{
    mat4 modelView = viewMatrix * modelMatrix;
    vec4 worldPos = modelView * vec4(inPosition, 1.0);
    mat3 normalMatrix = transpose(inverse(mat3(modelView)));

    position = worldPos.xyz;
    color = inColor;
    texCoord = inTexCoord;
    normal = normalize(normalMatrix * normalize(inNormal));

    gl_Position	= projMatrix * worldPos;
}